@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use base 'Import::Export';
 
@@ -16,7 +16,7 @@ require XSLoader;
 XSLoader::load("Term::ANSI::Sprintf", $VERSION);
 
 sub _sprintf {
-	my ($str, @params) = @_;
+	my ($self, $str, @params) = @_;
 	return CORE::sprintf($str, @params);
 }
 
@@ -30,7 +30,7 @@ Term::ANSI::Sprintf - sprintf with ANSI colors
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =head1 SYNOPSIS
 
